@@ -3,16 +3,16 @@ use warnings;
 
 package Template::Transformer;
 {
-  $Template::Transformer::VERSION = '1.0';
+  $Template::Transformer::VERSION = '1.01';
 }
 
 use Carp;
 use Data::Dumper;
 use Hash::Util qw(lock_hashref);
-use Log::Log4perl;
+use Log::Any;
 use Safe;
 
-my $logger = Log::Log4perl->get_logger();
+my $logger = Log::Any->get_logger();
 
 sub new {
     return bless( {}, shift )->_init(@_);
@@ -134,7 +134,7 @@ Template::Transformer
 
 =head1 VERSION
 
-version 1.0
+version 1.01
 
 =head1 AUTHOR
 
